# sisosign

For those times when you are pair programming and the story is running longer than expected. Someone needs to go but you can't decide who should stay on the story.

Why not have a computer make these tough choices for you? **sisosign** makes it easy.

## Installation

```pip install sisosign```

You might need `sudo` depending on your setup.

## Example usage

`sisosign firstname1 firstname2`

This will print a message informing you of who should stay. Et voila! Problem solved.

## Conclusion

That's it. It doesn't do anything else.
